/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 *
 */
package org.xwiki.container;

import org.xwiki.component.annotation.ComponentRole;

/**
 * Allows interested components to perform startup / shutdown tasks and be notified when the {@link ApplicationContext}
 * is created / being destroyed.
 * 
 * @version $Id: da763e840004bd390d60efd166fd827845906822 $
 * @since 1.9M2
 */
@ComponentRole
public interface ApplicationContextListener
{
    /**
     * Invoked when the {@link ApplicationContext} is created.
     * 
     * @param applicationContext the {@link ApplicationContext}.
     */
    void initializeApplicationContext(ApplicationContext applicationContext);

    /**
     * Invoked just before {@link ApplicationContext} is destroyed.
     * 
     * @param applicationContext the {@link ApplicationContext}.
     */
    void destroyApplicationContext(ApplicationContext applicationContext);
}
